@@ -27,12 +27,15 @@ public slots:
     void playVideo(const QString &url);
     void deleteVideo(const QString &path);
     void convertToAudio(const QString &input);
+    QString archiveFileExists(const QString &filePath, const QString &archivePath);
+    bool pathExists(const QString &path);
 
 private slots:
     void conversionFinished(int exitCode, QProcess::ExitStatus exitStatus);
+//    void setWindowGeometry();
 
 private:
-    QmlApplicationViewer* m_view;
+    QmlApplicationViewer *m_view;
     QString mediaPlayer;
     QProcess *converter;
     QString inputFile;
